"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.insertHandle = void 0;
const handle_1 = require("./handle");
/**
 * Inserts a handle and contain it if {@link InsertHandleParam.containerLinkId} is not null
 *
 * @example
 * #### Insert a handle link
```ts
await insertHandle({
   deep,
   handle: Handle.Insert \/\* Handle.Update, Handle.Delete \*\/,
   triggerTypeLinkId: await deep.id(deep.linkId, "MyType"),
   containerLinkId: deep.linkId
})
```
 */
function insertHandle(param) {
    return __awaiter(this, void 0, void 0, function* () {
        const { deep, handle, triggerTypeLinkId, containerLinkId } = param;
        const insertData = {
            type_id: yield deep.id('@deep-foundation/core', `Handle${handle_1.Handle[handle]}`),
            from_id: triggerTypeLinkId,
            to_id: yield deep.id('@deep-foundation/logger', `${handle_1.Handle[handle]}Handler`),
            in: {
                data: containerLinkId === null
                    ? []
                    : [
                        {
                            type_id: yield deep.id('@deep-foundation/core', 'Contain'),
                            from_id: containerLinkId !== null && containerLinkId !== void 0 ? containerLinkId : deep.linkId,
                        },
                    ],
            },
        };
        return yield deep.insert(insertData);
    });
}
exports.insertHandle = insertHandle;
